### Name: dyn.load
### Title: Foreign Function Interface
### Aliases: dyn.load dyn.unload is.loaded symbol.C symbol.For
### Keywords: interface

### ** Examples

is.loaded("hcass2") #-> probably TRUE, as stats is loaded



